==> rc-ui-lib-2.1.1.tgz: package/lib/dialog/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_utils = require("../utils");
var import_Dialog = __toESM(require("./Dialog"));
var import_getContainer = require("../utils/dom/getContainer");
var import_render = require("../utils/dom/render");
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
const Dialog = import_Dialog.default;
Dialog.show = (props) => {
  const defaultOptions = {
    overlay: true,
    closeable: false,
    closeIcon: "cross",
    lockScroll: true,
    transition: "rc-dialog-bounce",
    showConfirmButton: true,
    showCancelButton: false,
    closeOnClickOverlay: false
  };
  const _a = props, {
    onClosed,
    onCancel = import_utils.noop,
    onConfirm = import_utils.noop,
    onClose = import_utils.noop,
    cancelProps,
    confirmProps
  } = _a, restProps = __objRest(_a, [
    "onClosed",
    "onCancel",
    "onConfirm",
    "onClose",
    "cancelProps",
    "confirmProps"
  ]);
  const userContainer = (0, import_getContainer.resolveContainer)(props.teleport);
  const container = document.createElement("div");
  userContainer.appendChild(container);
  let destroy = import_utils.noop;
  const TempDialog = () => {
    const [visible, setVisible] = (0, import_react.useState)(false);
    const [cancelLoading, setCancelLoading] = (0, import_react.useState)(false);
    const [okLoading, setOkLoading] = (0, import_react.useState)(false);
    (0, import_react.useEffect)(() => {
      setVisible(true);
    }, []);
    destroy = () => {
      setVisible(false);
      if (onClose)
        onClose();
    };
    const _afterClose = () => {
      if (onClosed) {
        onClosed();
      }
      const unmountResult = (0, import_render.unmount)(container);
      if (unmountResult && container.parentNode) {
        container.parentNode.removeChild(container);
      }
    };
    const _onConfirm = (e) => __async(void 0, null, function* () {
      const i = setTimeout(() => setOkLoading(true));
      if ((yield onConfirm(e)) !== false) {
        clearTimeout(i);
        destroy();
      } else {
        clearTimeout(i);
        setOkLoading(false);
      }
    });
    const _onCancel = (e, clickOverlay) => __async(void 0, null, function* () {
      if (clickOverlay) {
        destroy();
        return;
      }
      const i = setTimeout(() => setCancelLoading(true));
      if ((yield onCancel(e)) !== false) {
        clearTimeout(i);
        destroy();
      } else {
        clearTimeout(i);
        setCancelLoading(false);
      }
    });
    return /* @__PURE__ */ import_react.default.createElement(import_Dialog.default, _extends({}, defaultOptions, restProps, {
      visible,
      teleport: () => container,
      cancelProps: __spreadValues({
        loading: cancelLoading
      }, cancelProps),
      confirmProps: __spreadValues({
        loading: okLoading
      }, confirmProps),
      onClose: destroy,
      onCancel: _onCancel,
      onConfirm: _onConfirm,
      onClosed: _afterClose
    }));
  };
  (0, import_render.render)(/* @__PURE__ */ import_react.default.createElement(TempDialog, null), container);
  return destroy;
};
Dialog.alert = (props) => {
  const {
    onConfirm = import_utils.noop
  } = props;
  return new Promise((resolve) => {
    Dialog.show(__spreadProps(__spreadValues({}, props), {
      onConfirm: (e) => {
        onConfirm(e);
        resolve(e);
      }
    }));
  });
};
Dialog.confirm = (props) => {
  const {
    onCancel = import_utils.noop,
    onConfirm = import_utils.noop
  } = props;
  return new Promise((resolve, reject) => {
    Dialog.show(__spreadProps(__spreadValues({
      // 强制显示 OK Btn
      confirmButtonText: "\u786E\u8BA4",
      showCancelButton: true
    }, props), {
      onCancel: (e) => {
        onCancel(e);
        reject();
      },
      onConfirm: (e) => {
        onConfirm(e);
        resolve(true);
      }
    }));
  });
};
var stdin_default = Dialog;

==> rc-ui-lib-2.1.3.tgz: package/lib/dialog/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_utils = require("../utils");
var import_Dialog = __toESM(require("./Dialog"));
var import_getContainer = require("../utils/dom/getContainer");
var import_render = require("../utils/dom/render");
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t)
        ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
const Dialog = import_Dialog.default;
Dialog.show = (props) => {
  const defaultOptions = {
    overlay: true,
    closeable: false,
    closeIcon: "cross",
    lockScroll: true,
    transition: "rc-dialog-bounce",
    showConfirmButton: true,
    showCancelButton: false,
    closeOnClickOverlay: false
  };
  const _a = props, {
    onClosed,
    onCancel = import_utils.noop,
    onConfirm = import_utils.noop,
    onClose = import_utils.noop,
    cancelProps,
    confirmProps
  } = _a, restProps = __objRest(_a, [
    "onClosed",
    "onCancel",
    "onConfirm",
    "onClose",
    "cancelProps",
    "confirmProps"
  ]);
  const userContainer = (0, import_getContainer.resolveContainer)(props.teleport);
  const container = document.createElement("div");
  userContainer.appendChild(container);
  let destroy = import_utils.noop;
  const TempDialog = () => {
    const [visible, setVisible] = (0, import_react.useState)(false);
    const [cancelLoading, setCancelLoading] = (0, import_react.useState)(false);
    const [okLoading, setOkLoading] = (0, import_react.useState)(false);
    (0, import_react.useEffect)(() => {
      setVisible(true);
    }, []);
    destroy = () => {
      setVisible(false);
      if (onClose)
        onClose();
    };
    const _afterClose = () => {
      if (onClosed) {
        onClosed();
      }
      const unmountResult = (0, import_render.unmount)(container);
      if (unmountResult && container.parentNode) {
        container.parentNode.removeChild(container);
      }
    };
    const _onConfirm = (e) => __async(void 0, null, function* () {
      const i = setTimeout(() => setOkLoading(true));
      if ((yield onConfirm(e)) !== false) {
        clearTimeout(i);
        destroy();
      } else {
        clearTimeout(i);
        setOkLoading(false);
      }
    });
    const _onCancel = (e, clickOverlay) => __async(void 0, null, function* () {
      if (clickOverlay) {
        destroy();
        return;
      }
      const i = setTimeout(() => setCancelLoading(true));
      if ((yield onCancel(e)) !== false) {
        clearTimeout(i);
        destroy();
      } else {
        clearTimeout(i);
        setCancelLoading(false);
      }
    });
    return /* @__PURE__ */ import_react.default.createElement(import_Dialog.default, _extends({}, defaultOptions, restProps, {
      visible,
      teleport: () => container,
      cancelProps: __spreadValues({
        loading: cancelLoading
      }, cancelProps),
      confirmProps: __spreadValues({
        loading: okLoading
      }, confirmProps),
      onClose: destroy,
      onCancel: _onCancel,
      onConfirm: _onConfirm,
      onClosed: _afterClose
    }));
  };
  (0, import_render.render)(/* @__PURE__ */ import_react.default.createElement(TempDialog, null), container);
  return destroy;
};
Dialog.alert = (props) => {
  const {
    onConfirm = import_utils.noop
  } = props;
  return new Promise((resolve) => {
    Dialog.show(__spreadProps(__spreadValues({}, props), {
      onConfirm: (e) => {
        onConfirm(e);
        resolve(e);
      }
    }));
  });
};
Dialog.confirm = (props) => {
  const {
    onCancel = import_utils.noop,
    onConfirm = import_utils.noop
  } = props;
  return new Promise((resolve, reject) => {
    Dialog.show(__spreadProps(__spreadValues({
      // 强制显示 OK Btn
      confirmButtonText: "\u786E\u8BA4",
      showCancelButton: true
    }, props), {
      onCancel: (e) => {
        onCancel(e);
        reject();
      },
      onConfirm: (e) => {
        onConfirm(e);
        resolve(true);
      }
    }));
  });
};
var stdin_default = Dialog;
